@@ -44,9 +44,11 @@ from tests.conftest import (
     ETHEREUM_ENCRYPTION_PASSWORD,
     ROOT_DIR,
 )
+from tests.helpers.docker.base import skip_docker_tests
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
+@skip_docker_tests
 class TestBuildDeployment(BaseCliTest):
     """Test `autonomy deply build deployment` command."""
 
